@@ -1,6 +1,9 @@
+import pytest
+
 from xopt.base import Xopt
 from xopt.evaluator import Evaluator
 from xopt.generators.bayesian.bayesian_exploration import BayesianExplorationGenerator
+from xopt.generators.bayesian.upper_confidence_bound import UpperConfidenceBoundOptions
 from xopt.resources.testing import TEST_VOCS_BASE, TEST_VOCS_DATA, xtest_callable
 
 
@@ -8,6 +11,11 @@ class TestBayesianExplorationGenerator:
     def test_init(self):
         BayesianExplorationGenerator(TEST_VOCS_BASE)
 
+        with pytest.raises(ValueError):
+            BayesianExplorationGenerator(
+                TEST_VOCS_BASE, UpperConfidenceBoundOptions()
+            )
+
     def test_generate(self):
         gen = BayesianExplorationGenerator(
             TEST_VOCS_BASE,
