@@ -2,14 +2,12 @@ import pandas as pd
 import torch
 from botorch import fit_gpytorch_model
 from botorch.models import ModelListGP, SingleTaskGP
-from botorch.models.transforms import Normalize, Standardize
+from botorch.models.transforms import Bilog, Normalize, Standardize
 from gpytorch import ExactMarginalLogLikelihood
 from gpytorch.kernels import MaternKernel, ScaleKernel
 from gpytorch.likelihoods import GaussianLikelihood
 from gpytorch.priors import GammaPrior
 
-from xopt.generators.bayesian.custom_botorch.bilog import Bilog
-
 
 def create_standard_model(
     input_data: pd.DataFrame,
@@ -32,6 +30,10 @@ def create_standard_model(
     """
     tkwargs = tkwargs or {"dtype": torch.double, "device": "cpu"}
 
+    # validate data
+    if len(input_data) == 0:
+        raise ValueError("input_data is empty/all Nans, cannot create model")
+
     train_X = torch.tensor(input_data.to_numpy(), **tkwargs)
     bounds = torch.tensor(bounds, **tkwargs)
     normalize = Normalize(train_X.shape[-1], bounds=bounds)
@@ -64,7 +66,7 @@ def create_standard_model(
             -1
         )
 
-        outcome_transform = Bilog(m=1)
+        outcome_transform = Bilog()
 
         # use conservative priors if requested
         covar_module = None
@@ -94,9 +96,8 @@ def create_standard_model(
         )
 
         if use_conservative_prior_mean:
-            models[-1].mean_module.constant = torch.nn.Parameter(
-                torch.tensor(5.0, **tkwargs), requires_grad=False
-            )
+            models[-1].mean_module.constant.data = torch.tensor(5.0, **tkwargs)
+            models[-1].mean_module.constant.requires_grad = False
 
         mll = ExactMarginalLogLikelihood(models[-1].likelihood, models[-1])
         fit_gpytorch_model(mll)
